@@ -23,5 +23,6 @@ module.exports = {
     ArrayGetRank: 21,
     ArraySetItem: 22,
     Array: 23,
-    RetrieveArray: 24
+    RetrieveArray: 24,
+    SetInstanceField: 25
 }
\ No newline at end of file
